@@ -1,10 +1,10 @@
-/* $Id: log-vbox.cpp 103594 2015-10-22 11:46:40Z bird $ */
+/* $Id: log-vbox.cpp 115341 2017-05-10 14:00:11Z fmehnert $ */
 /** @file
  * VirtualBox Runtime - Logging configuration.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2016 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -128,13 +128,15 @@
 *********************************************************************************************************************************/
 #ifdef IN_RING3
 # if defined(RT_OS_WINDOWS)
-#  include <Windows.h>
+#  include <iprt/win/windows.h>
 # elif defined(RT_OS_LINUX)
 #  include <unistd.h>
-# elif defined(RT_OS_FREEBSD)
+# elif defined(RT_OS_FREEBSD) || defined(RT_OS_NETBSD)
 #  include <sys/param.h>
 #  include <sys/sysctl.h>
-#  include <sys/user.h>
+#  if defined(RT_OS_FREEBSD)
+#    include <sys/user.h>
+#  endif
 #  include <stdlib.h>
 #  include <unistd.h>
 # elif defined(RT_OS_HAIKU)
@@ -207,28 +209,41 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(DEFAULT);
     ASSERT_LOG_GROUP(AUDIO_MIXER);
     ASSERT_LOG_GROUP(AUDIO_MIXER_BUFFER);
+    ASSERT_LOG_GROUP(AUTOLOGON);
     ASSERT_LOG_GROUP(CFGM);
     ASSERT_LOG_GROUP(CPUM);
     ASSERT_LOG_GROUP(CSAM);
     ASSERT_LOG_GROUP(DBGC);
     ASSERT_LOG_GROUP(DBGF);
     ASSERT_LOG_GROUP(DBGF_INFO);
+    ASSERT_LOG_GROUP(DBGG);
     ASSERT_LOG_GROUP(DEV);
     ASSERT_LOG_GROUP(DEV_AC97);
     ASSERT_LOG_GROUP(DEV_ACPI);
     ASSERT_LOG_GROUP(DEV_APIC);
+    ASSERT_LOG_GROUP(DEV_BUSLOGIC);
+    ASSERT_LOG_GROUP(DEV_DMA);
+    ASSERT_LOG_GROUP(DEV_E1000);
+    ASSERT_LOG_GROUP(DEV_EFI);
+    ASSERT_LOG_GROUP(DEV_EHCI);
     ASSERT_LOG_GROUP(DEV_FDC);
+    ASSERT_LOG_GROUP(DEV_GIM);
     ASSERT_LOG_GROUP(DEV_HDA);
     ASSERT_LOG_GROUP(DEV_HDA_CODEC);
     ASSERT_LOG_GROUP(DEV_HPET);
     ASSERT_LOG_GROUP(DEV_IDE);
+    ASSERT_LOG_GROUP(DEV_INIP);
     ASSERT_LOG_GROUP(DEV_KBD);
     ASSERT_LOG_GROUP(DEV_LPC);
-    ASSERT_LOG_GROUP(DEV_NE2000);
+    ASSERT_LOG_GROUP(DEV_LSILOGICSCSI);
+    ASSERT_LOG_GROUP(DEV_NVME);
+    ASSERT_LOG_GROUP(DEV_OHCI);
+    ASSERT_LOG_GROUP(DEV_PARALLEL);
     ASSERT_LOG_GROUP(DEV_PC);
     ASSERT_LOG_GROUP(DEV_PC_ARCH);
     ASSERT_LOG_GROUP(DEV_PC_BIOS);
     ASSERT_LOG_GROUP(DEV_PCI);
+    ASSERT_LOG_GROUP(DEV_PCI_RAW);
     ASSERT_LOG_GROUP(DEV_PCNET);
     ASSERT_LOG_GROUP(DEV_PIC);
     ASSERT_LOG_GROUP(DEV_PIT);
@@ -237,35 +252,243 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(DEV_SERIAL);
     ASSERT_LOG_GROUP(DEV_SMC);
     ASSERT_LOG_GROUP(DEV_VGA);
+    ASSERT_LOG_GROUP(DEV_VIRTIO);
+    ASSERT_LOG_GROUP(DEV_VIRTIO_NET);
     ASSERT_LOG_GROUP(DEV_VMM);
+    ASSERT_LOG_GROUP(DEV_VMM_BACKDOOR);
     ASSERT_LOG_GROUP(DEV_VMM_STDERR);
+    ASSERT_LOG_GROUP(DEV_VMSVGA);
+    ASSERT_LOG_GROUP(DEV_XHCI);
     ASSERT_LOG_GROUP(DIS);
     ASSERT_LOG_GROUP(DRV);
     ASSERT_LOG_GROUP(DRV_ACPI);
     ASSERT_LOG_GROUP(DRV_AUDIO);
     ASSERT_LOG_GROUP(DRV_BLOCK);
+    ASSERT_LOG_GROUP(DRV_CHAR);
+    ASSERT_LOG_GROUP(DRV_DISK_INTEGRITY);
+    ASSERT_LOG_GROUP(DRV_DISPLAY);
     ASSERT_LOG_GROUP(DRV_FLOPPY);
     ASSERT_LOG_GROUP(DRV_HOST_AUDIO);
+    ASSERT_LOG_GROUP(DRV_HOST_BASE);
     ASSERT_LOG_GROUP(DRV_HOST_DVD);
     ASSERT_LOG_GROUP(DRV_HOST_FLOPPY);
+    ASSERT_LOG_GROUP(DRV_HOST_PARALLEL);
+    ASSERT_LOG_GROUP(DRV_HOST_SERIAL);
+    ASSERT_LOG_GROUP(DRV_INTNET);
     ASSERT_LOG_GROUP(DRV_ISO);
     ASSERT_LOG_GROUP(DRV_KBD_QUEUE);
+    ASSERT_LOG_GROUP(DRV_LWIP);
+    ASSERT_LOG_GROUP(DRV_MINIPORT);
     ASSERT_LOG_GROUP(DRV_MOUSE_QUEUE);
+    ASSERT_LOG_GROUP(DRV_NAMEDPIPE);
     ASSERT_LOG_GROUP(DRV_NAT);
     ASSERT_LOG_GROUP(DRV_RAW_IMAGE);
+    ASSERT_LOG_GROUP(DRV_SCSI);
+    ASSERT_LOG_GROUP(DRV_SCSIHOST);
+    ASSERT_LOG_GROUP(DRV_TCP);
+    ASSERT_LOG_GROUP(DRV_TRANSPORT_ASYNC);
     ASSERT_LOG_GROUP(DRV_TUN);
+    ASSERT_LOG_GROUP(DRV_UDPTUNNEL);
     ASSERT_LOG_GROUP(DRV_USBPROXY);
     ASSERT_LOG_GROUP(DRV_VBOXHDD);
+    ASSERT_LOG_GROUP(DRV_VD);
     ASSERT_LOG_GROUP(DRV_VRDE_AUDIO);
     ASSERT_LOG_GROUP(DRV_VSWITCH);
     ASSERT_LOG_GROUP(DRV_VUSB);
     ASSERT_LOG_GROUP(EM);
+    ASSERT_LOG_GROUP(FTM);
+    ASSERT_LOG_GROUP(GIM);
+    ASSERT_LOG_GROUP(GMM);
+    ASSERT_LOG_GROUP(GUEST_CONTROL);
+    ASSERT_LOG_GROUP(GUEST_DND);
     ASSERT_LOG_GROUP(GUI);
+    ASSERT_LOG_GROUP(GVMM);
     ASSERT_LOG_GROUP(HGCM);
+    ASSERT_LOG_GROUP(HGSMI);
     ASSERT_LOG_GROUP(HM);
+    ASSERT_LOG_GROUP(IEM);
     ASSERT_LOG_GROUP(IOM);
+    ASSERT_LOG_GROUP(IPC);
     ASSERT_LOG_GROUP(LWIP);
+    ASSERT_LOG_GROUP(LWIP_API_LIB);
+    ASSERT_LOG_GROUP(LWIP_API_MSG);
+    ASSERT_LOG_GROUP(LWIP_ETHARP);
+    ASSERT_LOG_GROUP(LWIP_ICMP);
+    ASSERT_LOG_GROUP(LWIP_IGMP);
+    ASSERT_LOG_GROUP(LWIP_INET);
+    ASSERT_LOG_GROUP(LWIP_IP4);
+    ASSERT_LOG_GROUP(LWIP_IP4_REASS);
+    ASSERT_LOG_GROUP(LWIP_IP6);
+    ASSERT_LOG_GROUP(LWIP_MEM);
+    ASSERT_LOG_GROUP(LWIP_MEMP);
+    ASSERT_LOG_GROUP(LWIP_NETIF);
+    ASSERT_LOG_GROUP(LWIP_PBUF);
+    ASSERT_LOG_GROUP(LWIP_RAW);
+    ASSERT_LOG_GROUP(LWIP_SOCKETS);
+    ASSERT_LOG_GROUP(LWIP_SYS);
+    ASSERT_LOG_GROUP(LWIP_TCP);
+    ASSERT_LOG_GROUP(LWIP_TCPIP);
+    ASSERT_LOG_GROUP(LWIP_TCP_CWND);
+    ASSERT_LOG_GROUP(LWIP_TCP_FR);
+    ASSERT_LOG_GROUP(LWIP_TCP_INPUT);
+    ASSERT_LOG_GROUP(LWIP_TCP_OUTPUT);
+    ASSERT_LOG_GROUP(LWIP_TCP_QLEN);
+    ASSERT_LOG_GROUP(LWIP_TCP_RST);
+    ASSERT_LOG_GROUP(LWIP_TCP_RTO);
+    ASSERT_LOG_GROUP(LWIP_TCP_WND);
+    ASSERT_LOG_GROUP(LWIP_TIMERS);
+    ASSERT_LOG_GROUP(LWIP_UDP);
     ASSERT_LOG_GROUP(MAIN);
+    ASSERT_LOG_GROUP(MAIN_ADDITIONSFACILITY);
+    ASSERT_LOG_GROUP(MAIN_ADDITIONSSTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_APPLIANCE);
+    ASSERT_LOG_GROUP(MAIN_AUDIOADAPTER);
+    ASSERT_LOG_GROUP(MAIN_BANDWIDTHCONTROL);
+    ASSERT_LOG_GROUP(MAIN_BANDWIDTHGROUP);
+    ASSERT_LOG_GROUP(MAIN_BANDWIDTHGROUPCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_BIOSSETTINGS);
+    ASSERT_LOG_GROUP(MAIN_CANSHOWWINDOWEVENT);
+    ASSERT_LOG_GROUP(MAIN_CLIPBOARDMODECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_CONSOLE);
+    ASSERT_LOG_GROUP(MAIN_CPUCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_CPUEXECUTIONCAPCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_DHCPSERVER);
+    ASSERT_LOG_GROUP(MAIN_DIRECTORY);
+    ASSERT_LOG_GROUP(MAIN_DISPLAY);
+    ASSERT_LOG_GROUP(MAIN_DISPLAYSOURCEBITMAP);
+    ASSERT_LOG_GROUP(MAIN_DNDBASE);
+    ASSERT_LOG_GROUP(MAIN_DNDMODECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_DNDSOURCE);
+    ASSERT_LOG_GROUP(MAIN_DNDTARGET);
+    ASSERT_LOG_GROUP(MAIN_EMULATEDUSB);
+    ASSERT_LOG_GROUP(MAIN_EVENT);
+    ASSERT_LOG_GROUP(MAIN_EVENTLISTENER);
+    ASSERT_LOG_GROUP(MAIN_EVENTSOURCE);
+    ASSERT_LOG_GROUP(MAIN_EVENTSOURCECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_EXTPACK);
+    ASSERT_LOG_GROUP(MAIN_EXTPACKBASE);
+    ASSERT_LOG_GROUP(MAIN_EXTPACKFILE);
+    ASSERT_LOG_GROUP(MAIN_EXTPACKMANAGER);
+    ASSERT_LOG_GROUP(MAIN_EXTPACKPLUGIN);
+    ASSERT_LOG_GROUP(MAIN_EXTRADATACANCHANGEEVENT);
+    ASSERT_LOG_GROUP(MAIN_EXTRADATACHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_FILE);
+    ASSERT_LOG_GROUP(MAIN_FRAMEBUFFER);
+    ASSERT_LOG_GROUP(MAIN_FRAMEBUFFEROVERLAY);
+    ASSERT_LOG_GROUP(MAIN_FSOBJINFO);
+    ASSERT_LOG_GROUP(MAIN_GUEST);
+    ASSERT_LOG_GROUP(MAIN_GUESTDIRECTORY);
+    ASSERT_LOG_GROUP(MAIN_GUESTDNDSOURCE);
+    ASSERT_LOG_GROUP(MAIN_GUESTDNDTARGET);
+    ASSERT_LOG_GROUP(MAIN_GUESTERRORINFO);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILE);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEIOEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEOFFSETCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEREADEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEREGISTEREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILESTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFILEWRITEEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTFSOBJINFO);
+    ASSERT_LOG_GROUP(MAIN_GUESTKEYBOARDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTMONITORCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTMOUSEEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTMULTITOUCHEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTOSTYPE);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESS);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSINPUTNOTIFYEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSIOEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSOUTPUTEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSREGISTEREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROCESSSTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTPROPERTYCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTSESSION);
+    ASSERT_LOG_GROUP(MAIN_GUESTSESSIONEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTSESSIONREGISTEREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTSESSIONSTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_GUESTUSERSTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_HOST);
+    ASSERT_LOG_GROUP(MAIN_HOSTNAMERESOLUTIONCONFIGURATIONCHANGEEVENT);
+    ASSERT_LOG_GROUP(MAIN_HOSTNETWORKINTERFACE);
+    ASSERT_LOG_GROUP(MAIN_HOSTPCIDEVICEPLUGEVENT);
+    ASSERT_LOG_GROUP(MAIN_HOSTUSBDEVICE);
+    ASSERT_LOG_GROUP(MAIN_HOSTUSBDEVICEFILTER);
+    ASSERT_LOG_GROUP(MAIN_HOSTVIDEOINPUTDEVICE);
+    ASSERT_LOG_GROUP(MAIN_INTERNALMACHINECONTROL);
+    ASSERT_LOG_GROUP(MAIN_INTERNALSESSIONCONTROL);
+    ASSERT_LOG_GROUP(MAIN_KEYBOARD);
+    ASSERT_LOG_GROUP(MAIN_KEYBOARDLEDSCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MACHINE);
+    ASSERT_LOG_GROUP(MAIN_MACHINEDATACHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MACHINEDEBUGGER);
+    ASSERT_LOG_GROUP(MAIN_MACHINEEVENT);
+    ASSERT_LOG_GROUP(MAIN_MACHINEREGISTEREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MACHINESTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MEDIUM);
+    ASSERT_LOG_GROUP(MAIN_MEDIUMATTACHMENT);
+    ASSERT_LOG_GROUP(MAIN_MEDIUMCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MEDIUMCONFIGCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MEDIUMFORMAT);
+    ASSERT_LOG_GROUP(MAIN_MEDIUMREGISTEREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MOUSE);
+    ASSERT_LOG_GROUP(MAIN_MOUSECAPABILITYCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_MOUSEPOINTERSHAPE);
+    ASSERT_LOG_GROUP(MAIN_MOUSEPOINTERSHAPECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATENGINE);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORK);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKALTEREVENT);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKCREATIONDELETIONEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKPORTFORWARDEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKSETTINGEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATNETWORKSTARTSTOPEVENT);
+    ASSERT_LOG_GROUP(MAIN_NATREDIRECTEVENT);
+    ASSERT_LOG_GROUP(MAIN_NETWORKADAPTER);
+    ASSERT_LOG_GROUP(MAIN_NETWORKADAPTERCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_PARALLELPORT);
+    ASSERT_LOG_GROUP(MAIN_PARALLELPORTCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_PCIADDRESS);
+    ASSERT_LOG_GROUP(MAIN_PCIDEVICEATTACHMENT);
+    ASSERT_LOG_GROUP(MAIN_PERFORMANCECOLLECTOR);
+    ASSERT_LOG_GROUP(MAIN_PERFORMANCEMETRIC);
+    ASSERT_LOG_GROUP(MAIN_PROCESS);
+    ASSERT_LOG_GROUP(MAIN_PROGRESS);
+    ASSERT_LOG_GROUP(MAIN_REUSABLEEVENT);
+    ASSERT_LOG_GROUP(MAIN_RUNTIMEERROREVENT);
+    ASSERT_LOG_GROUP(MAIN_SERIALPORT);
+    ASSERT_LOG_GROUP(MAIN_SERIALPORTCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SESSION);
+    ASSERT_LOG_GROUP(MAIN_SESSIONSTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SHAREDFOLDER);
+    ASSERT_LOG_GROUP(MAIN_SHAREDFOLDERCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SHOWWINDOWEVENT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOTCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOTDELETEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOTEVENT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOTRESTOREDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SNAPSHOTTAKENEVENT);
+    ASSERT_LOG_GROUP(MAIN_STATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_STORAGECONTROLLER);
+    ASSERT_LOG_GROUP(MAIN_STORAGECONTROLLERCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_STORAGEDEVICECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_SYSTEMPROPERTIES);
+    ASSERT_LOG_GROUP(MAIN_TOKEN);
+    ASSERT_LOG_GROUP(MAIN_USBCONTROLLER);
+    ASSERT_LOG_GROUP(MAIN_USBCONTROLLERCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_USBDEVICE);
+    ASSERT_LOG_GROUP(MAIN_USBDEVICEFILTERS);
+    ASSERT_LOG_GROUP(MAIN_USBDEVICESTATECHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_VBOXSVCAVAILABILITYCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_VIRTUALBOX);
+    ASSERT_LOG_GROUP(MAIN_VIRTUALBOXCLIENT);
+    ASSERT_LOG_GROUP(MAIN_VIRTUALSYSTEMDESCRIPTION);
+    ASSERT_LOG_GROUP(MAIN_VRDESERVER);
+    ASSERT_LOG_GROUP(MAIN_VRDESERVERCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_VRDESERVERINFO);
+    ASSERT_LOG_GROUP(MAIN_VRDESERVERINFOCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MISC);
     ASSERT_LOG_GROUP(MM);
     ASSERT_LOG_GROUP(MM_HEAP);
     ASSERT_LOG_GROUP(MM_HYPER);
@@ -273,15 +496,24 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(MM_PHYS);
     ASSERT_LOG_GROUP(MM_POOL);
     ASSERT_LOG_GROUP(NAT_SERVICE);
+    ASSERT_LOG_GROUP(NET_ADP_DRV);
+    ASSERT_LOG_GROUP(NET_FLT_DRV);
     ASSERT_LOG_GROUP(NET_SERVICE);
+    ASSERT_LOG_GROUP(NET_SHAPER);
     ASSERT_LOG_GROUP(PATM);
     ASSERT_LOG_GROUP(PDM);
+    ASSERT_LOG_GROUP(PDM_ASYNC_COMPLETION);
+    ASSERT_LOG_GROUP(PDM_BLK_CACHE);
     ASSERT_LOG_GROUP(PDM_DEVICE);
     ASSERT_LOG_GROUP(PDM_DRIVER);
     ASSERT_LOG_GROUP(PDM_LDR);
     ASSERT_LOG_GROUP(PDM_QUEUE);
     ASSERT_LOG_GROUP(PGM);
+    ASSERT_LOG_GROUP(PGM_DYNMAP);
+    ASSERT_LOG_GROUP(PGM_PHYS);
+    ASSERT_LOG_GROUP(PGM_PHYS_ACCESS);
     ASSERT_LOG_GROUP(PGM_POOL);
+    ASSERT_LOG_GROUP(PGM_SHARED);
     ASSERT_LOG_GROUP(REM);
     ASSERT_LOG_GROUP(REM_DISAS);
     ASSERT_LOG_GROUP(REM_HANDLER);
@@ -290,14 +522,43 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(REM_PRINTF);
     ASSERT_LOG_GROUP(REM_RUN);
     ASSERT_LOG_GROUP(SELM);
+    ASSERT_LOG_GROUP(SHARED_CLIPBOARD);
+    ASSERT_LOG_GROUP(SHARED_CROPENGL);
+    ASSERT_LOG_GROUP(SHARED_FOLDERS);
+    ASSERT_LOG_GROUP(SHARED_OPENGL);
+    ASSERT_LOG_GROUP(SRV_INTNET);
     ASSERT_LOG_GROUP(SSM);
     ASSERT_LOG_GROUP(STAM);
     ASSERT_LOG_GROUP(SUP);
     ASSERT_LOG_GROUP(TM);
     ASSERT_LOG_GROUP(TRPM);
+    ASSERT_LOG_GROUP(USB_CARDREADER);
+    ASSERT_LOG_GROUP(USB_DRV);
+    ASSERT_LOG_GROUP(USB_FILTER);
+    ASSERT_LOG_GROUP(USB_KBD);
+    ASSERT_LOG_GROUP(USB_MOUSE);
+    ASSERT_LOG_GROUP(USB_MSD);
+    ASSERT_LOG_GROUP(USB_REMOTE);
+    ASSERT_LOG_GROUP(USB_WEBCAM);
+    ASSERT_LOG_GROUP(VGDRV);
+    ASSERT_LOG_GROUP(VBGL);
+    ASSERT_LOG_GROUP(VD);
+    ASSERT_LOG_GROUP(VD_DMG);
+    ASSERT_LOG_GROUP(VD_ISCSI);
+    ASSERT_LOG_GROUP(VD_PARALLELS);
+    ASSERT_LOG_GROUP(VD_QCOW);
+    ASSERT_LOG_GROUP(VD_QED);
+    ASSERT_LOG_GROUP(VD_RAW);
+    ASSERT_LOG_GROUP(VD_VDI);
+    ASSERT_LOG_GROUP(VD_VHD);
+    ASSERT_LOG_GROUP(VD_VHDX);
+    ASSERT_LOG_GROUP(VD_VMDK);
     ASSERT_LOG_GROUP(VM);
     ASSERT_LOG_GROUP(VMM);
+    ASSERT_LOG_GROUP(VRDE);
     ASSERT_LOG_GROUP(VRDP);
+    ASSERT_LOG_GROUP(VSCSI);
+    ASSERT_LOG_GROUP(WEBSERVICE);
 #undef ASSERT_LOG_GROUP
 #undef ASSERT_LOG_GROUP2
 #endif /* IN_RING3 */
@@ -388,13 +649,20 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
             RTLogLoggerEx(pLogger, 0, ~0U, "Commandline: %.64s\n", info.args);
         }
 
-#  elif defined(RT_OS_FREEBSD)
+#  elif defined(RT_OS_FREEBSD) || defined(RT_OS_NETBSD)
         /* Retrieve the required length first */
         int aiName[4];
+#  if defined(RT_OS_FREEBSD)
         aiName[0] = CTL_KERN;
         aiName[1] = KERN_PROC;
         aiName[2] = KERN_PROC_ARGS;     /* Introduced in FreeBSD 4.0 */
         aiName[3] = getpid();
+#  elif defined(RT_OS_NETBSD)
+        aiName[0] = CTL_KERN;
+        aiName[1] = KERN_PROC_ARGS;
+        aiName[2] = getpid();
+        aiName[3] = KERN_PROC_ARGV;
+#  endif
         size_t cchArgs = 0;
         int rcBSD = sysctl(aiName, RT_ELEMENTS(aiName), NULL, &cchArgs, NULL, 0);
         if (cchArgs > 0)
@@ -464,6 +732,8 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
         RTLogFlags(pLogger, "enabled unbuffered pid tid");
 #  ifndef IN_GUEST
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER | RTLOGDEST_STDOUT;
+#  else
+        RTLogGroupSettings(pLogger, "all=~0 -default.l6.l5.l4.l3");
 #  endif
 # endif
 # if defined(DEBUG_sandervl) && !defined(IN_GUEST)
@@ -477,7 +747,8 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER;
 # endif
 # if defined(DEBUG_aleksey)  /* Guest ring-0 as well */
-        RTLogGroupSettings(pLogger, "net_flt_drv.e.l.f.l3.l4.l5 +net_adp_drv.e.l.f.l3.l4.l5");
+        //RTLogGroupSettings(pLogger, "net_flt_drv.e.l.f.l3.l4.l5 +net_adp_drv.e.l.f.l3.l4.l5");
+        RTLogGroupSettings(pLogger, "net_flt_drv.e.l.f.l3.l4.l5.l6");
         RTLogFlags(pLogger, "enabled unbuffered");
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER | RTLOGDEST_STDOUT;
 # endif
@@ -491,7 +762,7 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER;
 # endif
 # if defined(DEBUG_michael) && defined(IN_GUEST)
-        RTLogGroupSettings(pLogger, "+all.e.l.f");
+        RTLogGroupSettings(pLogger, "+vga.e.l.f");
         RTLogFlags(pLogger, "enabled unbuffered");
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER | RTLOGDEST_STDOUT;
 # endif
